@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2011-2020 The Octave Project Developers
+// Copyright (C) 2011-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -34,11 +34,12 @@
 #include "QtHandlesUtils.h"
 
 #include "octave-qobject.h"
+#include "octave-qtutils.h"
 
-namespace QtHandles
+namespace octave
 {
 
-  PopupMenuControl*
+  PopupMenuControl *
   PopupMenuControl::create (octave::base_qobject& oct_qobj,
                             octave::interpreter& interp,
                             const graphics_object& go)
@@ -69,8 +70,8 @@ namespace QtHandles
 
     update (uicontrol::properties::ID_VALUE);
 
-    connect (box, SIGNAL (activated (int)),
-             SLOT (currentIndexChanged (int)));
+    connect (box, QOverload<int>::of (&QComboBox::activated),
+             this, &PopupMenuControl::currentIndexChanged);
   }
 
   PopupMenuControl::~PopupMenuControl (void)
