@@ -1,39 +1,43 @@
-/*
-
-Copyright (C) 2012-2019 Richard Crozier
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2012-2022 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if ! defined (octave_octave_dock_widget_h)
 #define octave_octave_dock_widget_h 1
 
 #include <QDockWidget>
-#include <QSettings>
 #include <QIcon>
-#include <QMainWindow>
-#include <QToolButton>
 #include <QMouseEvent>
+#include <QToolButton>
 
-#include "octave-cmd.h"
+#include "gui-settings.h"
+#include "qt-interpreter-events.h"
 
 namespace octave
 {
+  class base_qobject;
+  class main_window;
 
   // The few decoration items common to both main window and variable editor.
 
@@ -43,7 +47,9 @@ namespace octave
 
   public:
 
-    label_dock_widget (QWidget *p = nullptr);
+    label_dock_widget (QWidget *p, base_qobject& oct_qobj);
+
+    ~label_dock_widget (void) = default;
 
     // set_title() uses the custom title bar while setWindowTitle() uses
     // the default title bar (with style sheets)
@@ -64,6 +70,8 @@ namespace octave
 
   protected:
 
+    base_qobject& m_octave_qobj;
+
     int m_icon_size;
     QWidget *m_title_widget;
     QToolButton *m_dock_button;
@@ -81,18 +89,22 @@ namespace octave
 
   public:
 
-    octave_dock_widget (const QString& obj_name, QWidget *p = nullptr);
+    octave_dock_widget (const QString& obj_name, QWidget *p,
+                        base_qobject& oct_qobj);
 
-    virtual ~octave_dock_widget (void) = default;
-
-    virtual void connect_visibility_changed (void);
+    ~octave_dock_widget (void) = default;
 
     void set_predecessor_widget (octave_dock_widget *prev_widget);
 
+    void set_main_window (main_window *mw);
+
+    void set_adopted (bool adopted = true) { m_adopted = adopted; }
+    bool adopted (void) const { return m_adopted; }
+
   signals:
 
     //! Custom signal that tells whether a user has clicked away that dock
-    //! widget, i.e the active dock widget has changed.
+    //! widget, i.e. the active dock widget has changed.
 
     void active_changed (bool active);
 
@@ -100,8 +112,6 @@ namespace octave
 
     void queue_make_widget (void);
 
-    void request_queue_cmd (octave_cmd *);
-
   protected:
 
     virtual void closeEvent (QCloseEvent *e);
@@ -112,31 +122,19 @@ namespace octave
 
   public slots:
 
-    virtual void focus (void)
-    {
-      if (! isVisible ())
-        setVisible (true);
+    virtual void activate (void);
 
-      setFocus ();
-      activateWindow ();
-      raise ();
-    }
+    virtual void handle_visibility (bool visible);
 
-    virtual void handle_visibility (bool visible)
-    {
-      if (visible && ! isFloating ())
-        focus ();
-    }
+    virtual void notice_settings (const gui_settings *) { }
 
-    virtual void notice_settings (const QSettings*) { }
+    virtual void save_settings (void);
 
-    void handle_settings (const QSettings*);
+    void init_window_menu_entry (void);
 
-    void handle_active_dock_changed (octave_dock_widget*, octave_dock_widget*);
+    void handle_settings (const gui_settings *);
 
-    QMainWindow * main_win (void) { return m_parent; }
-
-    void save_settings (void);
+    void handle_active_dock_changed (octave_dock_widget *, octave_dock_widget *);
 
     void moveEvent (QMoveEvent *event);
 
@@ -150,13 +148,7 @@ namespace octave
 
   protected slots:
 
-    //! Slot to steer changing visibility from outside.
-
-    virtual void handle_visibility_changed (bool visible)
-    {
-      if (visible)
-        emit active_changed (true);
-    }
+    virtual void toplevel_change (bool);
 
     //! Event filter for double clicks into the window decoration elements.
 
@@ -165,7 +157,6 @@ namespace octave
   private slots:
 
     void change_visibility (bool);
-    void toplevel_change (bool);
 
   private:
 
@@ -175,9 +166,11 @@ namespace octave
 
     //! Stores the parent, since we are reparenting to 0.
 
-    QMainWindow *m_parent;
+    main_window *m_main_window;
 
+    bool m_adopted;
     bool m_custom_style;
+    bool m_focus_follows_mouse;
     int m_title_3d;
     QColor m_bg_color;
     QColor m_bg_color_active;
@@ -187,9 +180,8 @@ namespace octave
     QString m_icon_color_active;
     octave_dock_widget *m_predecessor_widget;
     QRect m_recent_float_geom;
-    QByteArray m_recent_dock_geom;
+    QRect m_recent_dock_geom;
     bool m_waiting_for_mouse_button_release;
-
   };
 }
 
