@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2016-2021 The Octave Project Developers
+// Copyright (C) 2016-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -30,13 +30,13 @@
 extern "C" {
 #endif
 
-extern void octave_set_default_fpucw (void);
+extern OCTAVE_API void octave_set_default_fpucw (void);
 
 // unsigned int must match the actual type of fpucw_t.
 
-extern unsigned int octave_begin_long_double_rounding (void);
+extern OCTAVE_API unsigned int octave_begin_long_double_rounding (void);
 
-extern void octave_end_long_double_rounding (unsigned int);
+extern OCTAVE_API void octave_end_long_double_rounding (unsigned int);
 
 #if defined __cplusplus
 }
