@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2016-2021 The Octave Project Developers
+// Copyright (C) 2016-2022 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -42,15 +42,15 @@ struct octave_getopt_options
 #define octave_required_arg 1
 #define octave_optional_arg 2
 
-extern int
+extern OCTAVE_API int
 octave_getopt_long_wrapper (int argc, char **argv,
                             const char *shortopts,
                             const struct octave_getopt_options *longopts,
                             int *longind);
 
-extern char * octave_optarg_wrapper (void);
+extern OCTAVE_API char * octave_optarg_wrapper (void);
 
-extern int octave_optind_wrapper (void);
+extern OCTAVE_API int octave_optind_wrapper (void);
 
 extern OCTAVE_API int octave_get_opterr_wrapper (void);
 extern OCTAVE_API int octave_set_opterr_wrapper (int val);
