@@ -1,4 +1,9 @@
-## Copyright (C) 2010-2018 Kai Habel
+########################################################################
+##
+## Copyright (C) 2010-2022 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,13 +20,14 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {[@var{fname}, @var{fpath}, @var{fltidx}] =} uigetfile ()
 ## @deftypefnx {} {[@dots{}] =} uigetfile (@var{flt})
 ## @deftypefnx {} {[@dots{}] =} uigetfile (@var{flt}, @var{dialog_name})
 ## @deftypefnx {} {[@dots{}] =} uigetfile (@var{flt}, @var{dialog_name}, @var{default_file})
-## @deftypefnx {} {[@dots{}] =} uigetfile (@dots{}, "Position", [@var{px} @var{py}])
 ## @deftypefnx {} {[@dots{}] =} uigetfile (@dots{}, "MultiSelect", @var{mode})
 ##
 ## Open a GUI dialog for selecting a file and return the filename @var{fname},
@@ -33,8 +39,9 @@
 ## @table @asis
 ## @item @qcode{"/path/to/filename.ext"}
 ## If a filename is given then the file extension is extracted and used as
-## filter.  In addition, the path is selected as current path and the filename
-## is selected as default file.  Example: @code{uigetfile ("myfun.m")}
+## filter.  In addition, the path is selected as current path in the dialog and
+## the filename is selected as default file.
+## Example: @code{uigetfile ("myfun.m")}
 ##
 ## @item A single file extension @qcode{"*.ext"}
 ## Example: @code{uigetfile ("*.ext")}
@@ -56,7 +63,7 @@
 ## is present the parent directory is listed.  The substring to the right of
 ## the rightmost file separator (if any) will be interpreted as a file or
 ## directory name and if that file or directory exists it will be highlighted.
-## If the path name or directory name is wholly or partly nonexistent, the
+## If the path name or directory name is entirely or partly nonexistent, the
 ## current working directory will be displayed.
 ## No filter will be active.
 ## @end table
@@ -66,16 +73,19 @@
 ## If @var{default_file} is given then it will be selected in the GUI dialog.
 ## If, in addition, a path is given it is also used as current path.
 ##
-## The screen position of the GUI dialog can be set using the
-## @qcode{"Position"} key and a 2-element vector containing the pixel
-## coordinates.  Two or more files can be selected when setting the
-## @qcode{"MultiSelect"} key to @qcode{"on"}.  In that case @var{fname} is a
-## cell array containing the files.
+## Two or more files can be selected when setting the @qcode{"MultiSelect"} key
+## to @qcode{"on"}.  In that case, @var{fname} is a cell array containing the
+## files.
+##
+## The outputs @var{fname} and @var{fpath} are strings returning the chosen
+## name and path, respectively.  However, if the @samp{Cancel} button is
+## clicked the outputs are of type double with a value of @code{0}.
+## @var{fltidx} is the index in the list of filter extensions @var{flt} that
+## was selected.
+##
 ## @seealso{uiputfile, uigetdir}
 ## @end deftypefn
 
-## Author: Kai Habel
-
 function [retfile, retpath, retindex] = uigetfile (varargin)
 
   if (nargin > 7)
@@ -86,7 +96,6 @@ function [retfile, retpath, retindex] = uigetfile (varargin)
   outargs = {cell(0, 2),         # File Filter
              "Open File",        # Dialog Title
              "",                 # Default filename
-             [240, 120],         # Dialog Position (pixel x/y)
              "off",              # MultiSelect on/off
              pwd};               # Default directory
 
@@ -100,7 +109,13 @@ function [retfile, retpath, retindex] = uigetfile (varargin)
     endif
   endif
 
-  optidx = min ([idx1, idx2, nargin+1]);
+  if (! isempty (idx2))
+    ## FIXME: Remove handling the "position" property completely in Octave 9
+    warning (['uigetfile: The "position" argument is deprecated and will ', ...
+              "be ignored. Consider removing it from the function call."]);
+  endif
+
+  optidx = min ([idx1, nargin+1]);
 
   args = varargin(1:optidx-1);
 
@@ -108,7 +123,7 @@ function [retfile, retpath, retindex] = uigetfile (varargin)
   if (len > 0)
     [outargs{1}, outargs{3}, defdir] = __file_filter__ ("uigetfile", args{1});
     if (! isempty (defdir))
-      outargs{6} = defdir;
+      outargs{5} = defdir;
     endif
   else
     outargs{1} = __file_filter__ ("uigetfile", outargs{1});
@@ -126,14 +141,14 @@ function [retfile, retpath, retindex] = uigetfile (varargin)
 
   if (len > 2)
     if (ischar (args{3}))
-      if (isdir (args{3}))
+      if (isfolder (args{3}))
         fdir = args{3};
         fname = fext = "";
       else
         [fdir, fname, fext] = fileparts (varargin{3});
       endif
       if (! isempty (fdir))
-        outargs{6} = fdir;
+        outargs{5} = fdir;
       endif
       if (! isempty (fname) || ! isempty (fext))
         outargs{3} = [fname fext];
@@ -155,23 +170,20 @@ function [retfile, retpath, retindex] = uigetfile (varargin)
       prop = varargin{i};
       val = varargin{i + 1};
       if (strcmpi (prop, "position"))
-        if (! isnumeric (val) || length (val) != 2)
-          error ('uigetfile: "Position" must be a 2-element vector');
-        endif
-        outargs{4} = val;
+        ## FIXME: Remove handling this option in Octave 9.
       elseif (strcmpi (prop, "multiselect"))
         if (! ischar (val))
           error ('uigetfile: MultiSelect value must be a string ("on"/"off")');
         endif
-        outargs{5} = tolower (val);
+        outargs{4} = tolower (val);
       else
         error ("uigetfile: unknown argument '%s'", prop);
       endif
     endfor
   endif
 
-  if (__octave_link_enabled__ ())
-    [retfile, retpath, retindex] = __octave_link_file_dialog__ (outargs{:});
+  if (__event_manager_have_dialogs__ ())
+    [retfile, retpath, retindex] = __event_manager_file_dialog__ (outargs{:});
   else
     funcname = __get_funcname__ (mfilename ());
     [retfile, retpath, retindex] = feval (funcname, outargs{:});
