@@ -1,20 +1,27 @@
-## Copyright (C) 1994-2017 John W. Eaton
+########################################################################
+##
+## Copyright (C) 1994-2022 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {} beta (@var{a}, @var{b})
@@ -36,15 +43,11 @@
 ##
 ## The Beta function can grow quite large and it is often more useful to work
 ## with the logarithm of the output rather than the function directly.
-## @xref{XREFbetaln,,betaln}, for computing the logarithm of the Beta function
-## in an efficient manner.
+## @xref{XREFbetaln,,@code{betaln}}, for computing the logarithm of the Beta
+## function in an efficient manner.
 ## @seealso{betaln, betainc, betaincinv}
 ## @end deftypefn
 
-## Author: KH <Kurt.Hornik@wu-wien.ac.at>
-## Created: 13 June 1993
-## Adapted-By: jwe
-
 function retval = beta (a, b)
 
   if (nargin != 2)
@@ -85,9 +88,8 @@ endfunction
 %! assert (zeros (size (a)), beta (a, -a), tol);
 %! assert (zeros (size (a)), beta (-a, a), tol);
 
-%!error beta ()
-%!error beta (1)
-%!error beta (1,2,3)
+%!error <Invalid call> beta ()
+%!error <Invalid call> beta (1)
 %!error <A and B must be real> beta (1i, 2)
 %!error <A and B must be real> beta (2, 1i)
 %!error <A and B must have consistent sizes> beta ([1 2], [1 2 3])
